;;;; wh-engine/package.lisp
;;;; root package of wh-engine

(defpackage wh-engine
  (:nicknames whe)
  (:use common-lisp 3d-vectors 3d-matrices)
  (:import-from sb-ext
                weak-pointer weak-pointer-p make-weak-pointer weak-pointer-value)
  (:export
   ;; main.lisp
   +version+ ensure-version
   deref-pointer points-to ensure-live
   vxy1 vxy-trunc
   make-id fixed-id
   *running-scenes*
   add-scene remove-scene get-scene update-all-scenes
   *view-width* *view-height* *view-ppu* *pixel-scale*
   register-test-scene
   run

   ;; serialization.lisp
   id-ref make-id-ref
   pointer
   deref-sus-pointer
   referize pointerize
   referize-setf pointerize-setf
   make-generic-load-form
   generate-load-forms
   dump-scene dump-actors
   load-resume-scene load-resume-actors

   ;; actor.lisp
   actor
   ; properties
   id name scene tags active-p parent children components destroyed-p
   location z-layer rotation scale matrix
   ; virtual properties
   tree-active-p
   world-matrix local-matrix
   world-location
   ; methods
   get-component add-component
   add-child remove-child
   has-tag add-tag remove-tag
   parent-deactivated parent-activated parent-changed
   deactivate activate
   resume suspend
   update
   destroy
   transform-point world-point local-point
   transform-svector transform-vector
   translate-by rotate-by scale-by

   ;; component.lisp
   component
   ; properties
   actor active-p started-p
   ; virtual properties
   scene destroyed-p
   ; methods
   attach
   parent-deactivated parent-activated parent-changed
   deactivate activate
   resume suspend
   start update
   destroy

   ;; scene.lisp
   scene
   ; properties
   id name actors destroyed-p
   ; methods
   add-actor remove-actor
   get-actor get-tagged-actors
   update
   destroy
   resume suspend

   ;; render/drawable.lisp
   drawable
   ; virtual properties
   culling-box
   ; methods
   draw

   drawable-test

   ;; render/view.lisp
   view
   ; properties
   render-pass render-mask cull-p
   ; virtual properties
   view-matrix world-matrix
   ; methods
   view-point render-view render-drawable
   ))
